```{eval-rst}
.. role:: small
```

```{eval-rst}
.. role:: smaller
```

```{include} basic.md
```

```{toctree}
:caption: 'General'
:hidden: true
:maxdepth: 1

installation.md
usage_principles.md
api/index.md
tutorials.md
release-notes/index.md
references.md
```

```{toctree}
:caption: 'Advanced Usage'
:hidden: true
:maxdepth: 1

memory_management.md
out_of_core.md
```

```{toctree}
:caption: 'Development'
:hidden: true
:maxdepth: 1

contributing.md
```

```{toctree}
:caption: 'About'
:hidden: true
:maxdepth: 1

acknowledgements.md
GitHub <https://github.com/scverse/rapids_singlecell>
Discourse <https://discourse.scverse.org/c/help/rsc/48>
```
